bibentries = c( # nolint start
  aalen_1978 = bibentry("article",
    title             = "Nonparametric Inference for a Family of Counting Processes",
    author            = "Odd Aalen",
    year              = 1978,
    journal           = "The Annals of Statistics",
    publisher         = "Institute of Mathematical Statistics",
    volume            = 6,
    number            = 4,
    pages             = "701--726",
    url               = "https://www.jstor.org/stable/2958850"
  ),
  begg_2000           = bibentry("article",
    title             = "Comparing tumour staging and grading systems: a case study and a review of the issues,  using thymoma as a model",
    author            = "Colin B. Begg and Laura D. Cramer and E. S. Venkatraman and Juan Rosai",
    year              = 2000,
    journal           = "Statistics in Medicine",
    publisher         = "Wiley",
    volume            = 19,
    number            = 15,
    pages             = "1997--2014",
    doi               = "10.1002/1097-0258(20000815)19:15<1997::aid-sim511>3.0.co;2-c"
  ),
  breiman_1984        = bibentry("book",
    title             = "Classification And Regression Trees",
    author            = "Leo Breiman and Jerome H. Friedman and Richard A. Olshen and Charles J. Stone",
    year              = 1984,
    publisher         = "Routledge",
    doi               = "10.1201/9781315139470"
  ),
  breiman_2001        = bibentry("article",
    title             = "Random Forests",
    author            = "Breiman, Leo",
    year              = 2001,
    journal           = "Machine Learning",
    volume            = 45,
    number            = 1,
    pages             = "5--32",
    doi               = "10.1023/A:1010933404324",
  ),
  buehlmann_2003      = bibentry("article",
    title             = "Boosting With the L2 Loss",
    author            = "Peter B\u00fchlmann and Bin Yu",
    year              = 2003,
    month             = "jun",
    journal           = "Journal of the American Statistical Association",
    publisher         = "Informa {UK} Limited",
    volume            = 98,
    number            = 462,
    pages             = "324--339",
    doi               = "10.1198/016214503000125"
  ),
  buehlmann_2006      = bibentry("article",
    title             = "Boosting for High-Dimensional Linear Models",
    author            = "Peter B\u00fchlmann",
    year              = 2006,
    journal           = "The Annals of Statistics",
    publisher         = "Institute of Mathematical Statistics",
    volume            = 34,
    number            = 2,
    pages             = "559--583",
    url               = "https://www.jstor.org/stable/25463430"
  ),
  buehlmann_2007      = bibentry("article",
    title             = "Boosting Algorithms: Regularization,  Prediction and Model Fitting",
    author            = "Peter B\u00fchlmann and Torsten Hothorn",
    year              = 2007,
    month             = "nov",
    journal           = "Statistical Science",
    publisher         = "Institute of Mathematical Statistics",
    volume            = 22,
    number            = 4,
    pages             = "477--505",
    doi               = "10.1214/07-sts242"
  ),
  burges_2010         = bibentry("techreport",
    title             = "From RankNet to LambdaRank to LambdaMART: An Overview",
    author            = "Burges, Chris J.C.",
    year              = 2010,
    month             = "jun",
    number            = "MSR-TR-2010-82",
    url               = "https://www.microsoft.com/en-us/research/publication/from-ranknet-to-lambdarank-to-lambdamart-an-overview/",
    institution       = "Microsoft Research"
  ),
  chambless_2006      = bibentry("article",
    title             = "Estimation of time-dependent area under the {ROC} curve for long-term risk prediction",
    author            = "Lloyd E. Chambless and Guoqing Diao",
    year              = 2006,
    journal           = "Statistics in Medicine",
    publisher         = "Wiley",
    volume            = 25,
    number            = 20,
    pages             = "3474--3486",
    doi               = "10.1002/sim.2299"
  ),
  cox_1972            = bibentry("article",
    title             = "Regression Models and Life-Tables",
    author            = "D. R. Cox",
    year              = 1972,
    month             = "jan",
    journal           = "Journal of the Royal Statistical Society: Series B (Methodological)",
    publisher         = "Wiley",
    volume            = 34,
    number            = 2,
    pages             = "187--202",
    doi               = "10.1111/j.2517-6161.1972.tb00899.x"
  ),
  freund_1996         = bibentry("inproceedings",
    title             = "Experiments with a new boosting algorithm",
    author            = "Freund, Yoav and Schapire, Robert E and others",
    year              = 1996,
    booktitle         = "In: Thirteenth International Conference on ML",
    volume            = 96,
    pages             = "148--156",
    organization      = "Citeseer"
  ),
  freund_1997         = bibentry("article",
    title             = "A Decision-Theoretic Generalization of On-Line Learning and an Application to Boosting",
    author            = "Yoav Freund and Robert E Schapire",
    year              = 1997,
    month             = "aug",
    journal           = "Journal of Computer and System Sciences",
    publisher         = "Elsevier {BV}",
    volume            = 55,
    number            = 1,
    pages             = "119--139",
    doi               = "10.1006/jcss.1997.1504"
  ),
  friedman_2000       = bibentry("article",
    title             = "Additive logistic regression: a statistical view of boosting (With discussion and a rejoinder by the authors)",
    author            = "Jerome Friedman and Trevor Hastie and Robert Tibshirani",
    year              = 2000,
    month             = "apr",
    journal           = "The Annals of Statistics",
    publisher         = "Institute of Mathematical Statistics",
    volume            = 28,
    number            = 2,
    pages             = "337--407",
    doi               = "10.1214/aos/1016218223"
  ),
  friedman_2001       = bibentry("article",
    title             = "Greedy Function Approximation: A Gradient Boosting Machine",
    author            = "Jerome H. Friedman",
    year              = 2001,
    journal           = "The Annals of Statistics",
    publisher         = "Institute of Mathematical Statistics",
    volume            = 29,
    number            = 5,
    pages             = "1189--1232",
    url               = "https://www.jstor.org/stable/2699986"
  ),
  friedman_2002       = bibentry("article",
    title             = "Stochastic gradient boosting",
    author            = "Jerome H. Friedman",
    year              = 2002,
    month             = "feb",
    journal           = "Computational Statistics & Data Analysis",
    publisher         = "Elsevier {BV}",
    volume            = 38,
    number            = 4,
    pages             = "367--378",
    doi               = "10.1016/s0167-9473(01)00065-2"
  ),
  friedman_2010       = bibentry("article",
    title             = "Regularization Paths for Generalized Linear Models via Coordinate Descent",
    author            = "Jerome Friedman and Trevor Hastie and Robert Tibshirani",
    year              = 2010,
    journal           = "Journal of Statistical Software",
    publisher         = "Foundation for Open Access Statistic",
    volume            = 33,
    number            = 1,
    doi               = "10.18637/jss.v033.i01"
  ),
  goeman_2009         = bibentry("article",
    title             = "L1Penalized Estimation in the Cox Proportional Hazards Model",
    author            = "Jelle J. Goeman",
    year              = 2009,
    month             = "nov",
    journal           = "Biometrical Journal",
    publisher         = "Wiley",
    pages             = "NA--NA",
    doi               = "10.1002/bimj.200900028"
  ),
  goenen_2005         = bibentry("article",
    title             = "Concordance probability and discriminatory power in proportional hazards regression",
    author            = "Mithat G\u00f6nen and Glenn Heller",
    year              = 2005,
    month             = "dec",
    journal           = "Biometrika",
    publisher         = "Oxford University Press ({OUP})",
    volume            = 92,
    number            = 4,
    pages             = "965--970",
    doi               = "10.1093/biomet/92.4.965"
  ),
  graf_1999           = bibentry("article",
    title             = "Assessment and comparison of prognostic classification schemes for survival data",
    author            = "Erika Graf and Claudia Schmoor and Willi Sauerbrei and Martin Schumacher",
    year              = 1999,
    month             = "sep",
    journal           = "Statistics in Medicine",
    publisher         = "Wiley",
    volume            = 18,
    number            = "17-18",
    pages             = "2529--2545",
    doi               = "10.1002/(sici)1097-0258(19990915/30)18:17/18<2529::aid-sim274>3.0.co;2-5"
  ),
  harrell_1982        = bibentry("article",
    title             = "Evaluating the yield of medical tests",
    author            = "Harrell, Frank E and Califf, Robert M and Pryor, David B and Lee, Kerry L and Rosati, Robert A",
    year              = 1982,
    journal           = "Jama",
    publisher         = "American Medical Association",
    volume            = 247,
    number            = 18,
    pages             = "2543--2546"
  ),
  hofner_2012         = bibentry("article",
    title             = "Model-based boosting in R: a hands-on tutorial using the R package mboost",
    author            = "Benjamin Hofner and Andreas Mayr and Nikolay Robinzonov and Matthias Schmid",
    year              = 2012,
    month             = "dec",
    journal           = "Computational Statistics",
    publisher         = "Springer Science and Business Media {LLC}",
    volume            = 29,
    number            = "1-2",
    pages             = "3--35",
    doi               = "10.1007/s00180-012-0382-5"
  ),
  hothorn_2006        = bibentry("article",
    title             = "Unbiased Recursive Partitioning: A Conditional Inference Framework",
    author            = "Torsten Hothorn and Kurt Hornik and Achim Zeileis",
    year              = 2006,
    month             = "sep",
    journal           = "Journal of Computational and Graphical Statistics",
    publisher         = "Informa {UK} Limited",
    volume            = 15,
    number            = 3,
    pages             = "651--674",
    doi               = "10.1198/106186006x133933"
  ),
  hothorn_2010        = bibentry("article",
    title             = "Model-based boosting 2.0",
    author            = "Hothorn, Torsten and B\u00fchlmann, Peter and Kneib, Thomas and Schmid, Matthias and Hofner, Benjamin",
    year              = 2010,
    journal           = "Journal of Machine Learning Research",
    volume            = 11,
    number            = "Aug",
    pages             = "2109--2113",
    url               = "https://www.jmlr.org/papers/v11/hothorn10a.html"
  ),
  hung_2010           = bibentry("article",
    title             = "Estimation methods for time-dependent AUC models with survival data",
    author            = "Hung Hung and Chin-Tsang Chiang",
    year              = 2010,
    journal           = "The Canadian Journal of Statistics / La Revue Canadienne de Statistique",
    publisher         = "Statistical Society of Canada, Wiley",
    volume            = 38,
    number            = 1,
    pages             = "8--26",
    url               = "https://www.jstor.org/stable/27805213"
  ),
  ishwaran_2008       = bibentry("article",
    title             = "Random survival forests",
    author            = "Ishwaran, Hemant and Kogalur, Udaya B and Blackstone, Eugene H and Lauer, Michael S and others",
    year              = 2008,
    journal           = "The annals of applied statistics",
    publisher         = "Institute of Mathematical Statistics",
    volume            = 2,
    number            = 3,
    pages             = "841--860"
  ),
  kalbfleisch_2002    = bibentry("book",
    title             = "The Statistical Analysis of Failure Time Data",
    author            = "John D. Kalbfleisch and Ross L. Prentice",
    year              = 2002,
    month             = "aug",
    publisher         = "John Wiley & Sons,  Inc.",
    doi               = "10.1002/9781118032985"
  ),
  kaplan_1958         = bibentry("article",
    title             = "Nonparametric Estimation from Incomplete Observations",
    author            = "E. L. Kaplan and Paul Meier",
    year              = 1958,
    month             = "jun",
    journal           = "Journal of the American Statistical Association",
    publisher         = "Informa {UK} Limited",
    volume            = 53,
    number            = 282,
    pages             = "457--481",
    doi               = "10.1080/01621459.1958.10501452"
  ),
  kneib_2008          = bibentry("article",
    title             = "Variable Selection and Model Choice in Geoadditive Regression Models",
    author            = "Thomas Kneib and Torsten Hothorn and Gerhard Tutz",
    year              = 2008,
    month             = "aug",
    journal           = "Biometrics",
    publisher         = "Wiley",
    volume            = 65,
    number            = 2,
    pages             = "626--634",
    doi               = "10.1111/j.1541-0420.2008.01112.x"
  ),
  kriegler_2007       = bibentry("phdthesis",
    title             = "Cost-Sensitive Stochastic Gradient Boosting Within a Quantitative Regression Framework",
    author            = "Kriegler, Brian",
    year              = 2007,
    url               = "https://dl.acm.org/citation.cfm?id=1354603",
    school            = "University of California at Los Angeles"
  ),
  nagelkerke_1991     = bibentry("article",
    title             = "A note on a general definition of the coefficient of determination",
    author            = "Nagelkerke, Nico JD and others",
    year              = 1991,
    journal           = "Biometrika",
    publisher         = "Oxford University Press",
    volume            = 78,
    number            = 3,
    pages             = "691--692"
  ),
  nelson_1969         = bibentry("article",
    title             = "Hazard Plotting for Incomplete Failure Data",
    author            = "Wayne Nelson",
    year              = 1969,
    month             = "jan",
    journal           = "Journal of Quality Technology",
    publisher         = "Informa {UK} Limited",
    volume            = 1,
    number            = 1,
    pages             = "27--52",
    doi               = "10.1080/00224065.1969.11980344"
  ),
  nelson_1972         = bibentry("article",
    title             = "Theory and Applications of Hazard Plotting for Censored Failure Data",
    author            = "Wayne Nelson",
    year              = 1972,
    month             = "nov",
    journal           = "Technometrics",
    publisher         = "Informa {UK} Limited",
    volume            = 14,
    number            = 4,
    pages             = "945--966",
    doi               = "10.1080/00401706.1972.10488991"
  ),
  oquigley_2005       = bibentry("article",
    title             = "Explained randomness in proportional hazards models",
    author            = "John O'Quigley and Ronghui Xu and Janez Stare",
    year              = 2005,
    journal           = "Statistics in Medicine",
    publisher         = "Wiley",
    volume            = 24,
    number            = 3,
    pages             = "479--489",
    doi               = "10.1002/sim.1946"
  ),
  ridgeway_1999       = bibentry("article",
    title             = "The state of boosting",
    author            = "Ridgeway, Greg",
    year              = 1999,
    journal           = "Computing Science and Statistics",
    number            = 31,
    pages             = "172--181"
  ),
  royston_2002        = bibentry("article",
    title             = "Flexible parametric proportional-hazards and proportional-odds models for censored survival data,  with application to prognostic modelling and estimation of treatment effects",
    author            = "Patrick Royston and Mahesh K. B. Parmar",
    year              = 2002,
    journal           = "Statistics in Medicine",
    publisher         = "Wiley",
    volume            = 21,
    number            = 15,
    pages             = "2175--2197",
    doi               = "10.1002/sim.1203"
  ),
  schmid_2008         = bibentry("article",
    title             = "Boosting additive models using component-wise P-Splines",
    author            = "Matthias Schmid and Torsten Hothorn",
    year              = 2008,
    month             = "dec",
    journal           = "Computational Statistics & Data Analysis",
    publisher         = "Elsevier {BV}",
    volume            = 53,
    number            = 2,
    pages             = "298--311",
    doi               = "10.1016/j.csda.2008.09.009"
  ),
  song_2008           = bibentry("article",
    title             = "A semiparametric approach for the covariate specific ROC curve with survival outcome",
    author            = "Song, Xiao and Zhou, Xiao-Hua",
    year              = 2008,
    journal           = "Statistica Sinica",
    volume            = 18,
    number            = 3,
    pages             = "947--65",
    url               = "https://www.jstor.org/stable/24308524"
  ),
  uno_2007            = bibentry("article",
    title             = "Evaluating Prediction Rules fort-Year Survivors With Censored Regression Models",
    author            = "Hajime Uno and Tianxi Cai and Lu Tian and L. J Wei",
    year              = 2007,
    month             = "jun",
    journal           = "Journal of the American Statistical Association",
    publisher         = "Informa {UK} Limited",
    volume            = 102,
    number            = 478,
    pages             = "527--537",
    doi               = "10.1198/016214507000000149"
  ),
  uno_2011            = bibentry("article",
    title             = "On the C-statistics for evaluating overall adequacy of risk prediction procedures with censored survival data",
    author            = "Hajime Uno and Tianxi Cai and Michael J. Pencina and Ralph B. D'Agostino and L. J. Wei",
    year              = 2011,
    journal           = "Statistics in Medicine",
    publisher         = "Wiley",
    pages             = "n/a--n/a",
    doi               = "10.1002/sim.4154"
  ),
  vanbelle_2010       = bibentry("article",
    title             = "Improved performance on high-dimensional survival data by application of Survival-{SVM}",
    author            = "V. Van Belle and K. Pelckmans and S. Van Huffel and J. A. K. Suykens",
    year              = 2010,
    month             = "nov",
    journal           = "Bioinformatics",
    publisher         = "Oxford University Press ({OUP})",
    volume            = 27,
    number            = 1,
    pages             = "87--94",
    doi               = "10.1093/bioinformatics/btq617"
  ),
  vanbelle_2011       = bibentry("article",
    title             = "Support vector methods for survival analysis: a comparison between ranking and regression approaches",
    author            = "Vanya Van Belle and Kristiaan Pelckmans and Sabine Van Huffel and Johan A.K. Suykens",
    year              = 2011,
    month             = "oct",
    journal           = "Artificial Intelligence in Medicine",
    publisher         = "Elsevier {BV}",
    volume            = 53,
    number            = 2,
    pages             = "107--118",
    doi               = "10.1016/j.artmed.2011.06.006"
  ),
  wright_2017         = bibentry("article",
    title             = "ranger: A Fast Implementation of Random Forests for High Dimensional Data in {C++} and {R}",
    author            = "Wright, Marvin N. and Ziegler, Andreas",
    year              = 2017,
    journal           = "Journal of Statistical Software",
    volume            = 77,
    number            = 1,
    pages             = "1--17",
    doi               = "10.18637/jss.v077.i01"
  ),
  xu_1999             = bibentry("article",
    title             = "A R2 type measure of dependence for proportional hazards models",
    author            = "Ronghui Xu and John O'Quigley",
    year              = 1999,
    month             = "jan",
    journal           = "Journal of Nonparametric Statistics",
    publisher         = "Informa {UK} Limited",
    volume            = 12,
    number            = 1,
    pages             = "83--107",
    doi               = "10.1080/10485259908832799"
  ),
  jaeger_2019         = bibentry("article",
    title             = "Oblique random survival forests",
    volume            = "13",
    url               = "https://projecteuclid.org/euclid.aoas/1571277776",
    doi               = "10.1214/19-AOAS1261",
    language          = "EN",
    number            = "3",
    urldate           = "2019-10-19",
    journal           = "The Annals of Applied Statistics",
    author            = "Jaeger, Byron C. and Long, D. Leann and Long, Dustin M. and Sims, Mario and Szychowski, Jeff M. and Min, Yuan-I. and Mcclure, Leslie A. and Howard, George and Simon, Noah",
    month             = "sep",
    year              = "2019",
    pages             = "1847--1883"
  ),
  silverman_1986      = bibentry("book",
    address           = "London",
    author            = "Silverman, B. W.",
    biburl            = "https://www.bibsonomy.org/bibtex/25c3b630fb0a76da55942a77551fde8a2/pierpaolo.pk81",
    description       = "WSD",
    publisher         = "Chapman & Hall",
    timestamp         = "2007-02-27T16:22:14.000+0100",
    title             = "Density Estimation for Statistics and Data Analysis",
    year              = 1986
  ),
  chen_2016           = bibentry("article",
    title             = "{XGBoost}: {A} {Scalable} {Tree} {Boosting} {System}",
    url               = "https://arxiv.org/abs/1603.02754",
    journal           = "Proceedings of the 22nd ACM SIGKDD International Conference on Knowledge Discovery and Data Mining - KDD '16",
    author            = "Chen, Tianqi and Guestrin, Carlos",
    year              = "2016",
    note              = "arXiv: 1603.02754",
    pages             = "785--794"
  ),
  binder_2009         = bibentry("article",
    author            = "Binder, H. and Allignol, A. and Schumacher, M. and Beyersmann, J.",
    year              = "2009",
    title             = "Boosting for high-dimensional time-to-event data with competing risks",
    journal           = "Bioinformatics",
    pages             = "890--896",
    volume            = "25"
  ),
  schemper_2000       = bibentry("article",
    author            = "Schemper, Michael and Henderson, Robin",
    doi               = "10.1002/sim.1486",
    journal           = "Biometrics",
    pages             = "249--255",
    pmid              = "12854094",
    title             = "Predictive Accuracy and Explained Variation in Cox Regression",
    volume            = "56",
    year              = "2000"
  ),
  schmid_2011         = bibentry("article",
    author            = "Schmid, Matthias and Hielscher, Thomas and Augustin, Thomas and Gefeller, Olaf",
    doi               = "10.1111/j.1541-0420.2010.01459.x",
    journal           = "Biometrics",
    number            = "2",
    pages             = "524--535",
    pmid              = "20618308",
    title             = "A Robust Alternative to the Schemper-Henderson Estimator of Prediction Error",
    volume            = "67",
    year              = "2011"
  ),
  vanhouwelingen_2000 = bibentry("article",
    author            = "Van Houwelingen, Hans C.",
    doi               = "10.1002/1097-0258(20001230)19:24<3401::AID-SIM554>3.0.CO;2-2",
    journal           = "Statistics in Medicine",
    number            = "24",
    pages             = "3401--3415",
    pmid              = "11122504",
    title             = "Validation, calibration, revision and combination of prognostic survival models",
    volume            = "19",
    year              = "2000"
  ),
  peto_1972           = bibentry("article",
    author            = "Peto, Richard and Peto, Julian",
    journal           = "Journal of the Royal Statistical Society: Series A (General)",
    number            = "2",
    pages             = "185--198",
    publisher         = "Wiley Online Library",
    title             = "Asymptotically efficient rank invariant test procedures",
    volume            = "135",
    year              = "1972"
  ),
  schemper_2009       = bibentry("article",
    author            = "Schemper, Michael and Wakounig, Samo and Heinze, Georg",
    doi               = "10.1002/sim.3623",
    journal           = "Statistics in Medicine",
    month             = "aug",
    number            = "19",
    pages             = "2473--2489",
    publisher         = "John Wiley & Sons, Ltd",
    title             = "The estimation of average hazard ratios by weighted Cox regression",
    volume            = "28",
    year              = "2009"
  ),
  vock_2016           = bibentry("article",
    author            = "Vock, David M and Wolfson, Julian and Bandyopadhyay, Sunayan and Adomavicius, Gediminas and Johnson, Paul E and Vazquez-Benitez, Gabriela and O'Connor, Patrick J",
    doi               = "https://doi.org/10.1016/j.jbi.2016.03.009",
    journal           = "Journal of Biomedical Informatics",
    pages             = "119--131",
    title             = "Adapting machine learning techniques to censored time-to-event health record data: A general-purpose approach using inverse probability of censoring weighting",
    url               = "https://www.sciencedirect.com/science/article/pii/S1532046416000496",
    volume            = "61",
    year              = "2016"
  ),
  jackson_2014        = bibentry("article",
    author            = "Jackson, Dan and White, Ian R. and Seaman, Shaun and Evans, Hannah and Baisley, Kathy and Carpenter, James",
    doi               = "10.1002/sim.6274",
    journal           = "Statistics in Medicine",
    month             = "nov",
    number            = "27",
    pages             = "4681--4694",
    publisher         = "John Wiley and Sons Ltd",
    title             = "Relaxing the independent censoring assumption in the Cox proportional hazards model using multiple imputation",
    volume            = "33",
    year              = "2014"
  ),
  klein_2003          = bibentry("book",
    author            = "Klein, John P and Moeschberger, Melvin L",
    edition           = "2",
    isbn              = "0387216456",
    publisher         = "Springer Science & Business Media",
    title             = "Survival analysis: techniques for censored and truncated data",
    year              = "2003"
  ),
  buckley_1979        = bibentry("article",
    author            = "Buckley, Jonathan and James, Ian",
    doi               = "10.2307/2335161",
    journal           = "Biometrika",
    month             = "apr",
    number            = "3",
    pages             = "429--436",
    publisher         = "Oxford University Press, Biometrika Trust",
    title             = "Linear Regression with Censored Data",
    url               = "https://www.jstor.org/stable/2335161",
    volume            = "66",
    year              = "1979"
  ),

  haider_2020         = bibentry("article",
    author            = "Haider, Humza and Hoehn, Bret and Davis, Sarah and Greiner, Russell",
    journal           = "Journal of Machine Learning Research",
    volume            = "21",
    number            = "85",
    pages             = "1--63",
    title             = "Effective Ways to Build and Evaluate Individual Survival Distributions",
    url               = "https://jmlr.org/papers/v21/18-772.html",
    year              = "2020"
  )
) # nolint end
